from .environment import Environment
from .configuration import Configuration
from .ludialudom import LudiaLudom

Environment.Sandbox = Environment(
    "sandbox", "http://ludialudomapi.ana.sk/api", "http://ludialudom.ana.sk/api"
)

Environment.Production = Environment(
    "production", "https://webapi.ludialudom.sk/api", "https://ludialudom.sk/api"
)
