from .environment import Environment


class Configuration(object):
    def __init__(self, environment: Environment, key: str, secret: str, client_id: int = 1, timeout: int = 30):
        self._environment = environment
        self._key = key
        self._secret = secret
        self._client_id = client_id
        self._timeout = timeout

    @property
    def environment(self) -> Environment:
        return self._environment

    @property
    def key(self) -> str:
        return self._key

    @property
    def secret(self) -> str:
        return self._secret

    @property
    def client_id(self):
        return self._client_id

    @property
    def timeout(self) -> int:
        return self._timeout
